@@ -1,11 +1,7 @@
-#!/usr/local/bin/python
+#!/usr/bin/env python
 # encoding: utf-8
 """
-# SHERLOCK #
-: INFERING TRANSIENT-SOURCE CLASSIFICATIONS FROM SPATIALLY CROSS-MATCHED CATALOGUED SOURCES :
-=============================================================================================
-
-Documentation for sherlock can be found here: http://qub-sherlock.readthedocs.org/en/stable
+Documentation for sherlock can be found here: http://sherlock.readthedocs.org
 
 .. todo ::
 
@@ -46,11 +42,11 @@ Options:
     -h, --help              show this help message
     -s, --settings          the settings file
     -b, --verbose           print more details to stdout
-    -l, --transientlistId   the id of the transient list to classify
     -u, --update            update the transient database with new classifications and crossmatches
     -v, --version           print the version of sherlock
 """
-################# GLOBAL IMPORTS ####################
+from __future__ import print_function
+from __future__ import absolute_import
 import sys
 import os
 os.environ['TERM'] = 'vt100'
@@ -59,77 +55,95 @@ import glob
 import pickle
 from docopt import docopt
 from fundamentals import tools, times
-from fundamentals.renderer import list_of_dictionaries
-from database_cleaner import database_cleaner
-from commonutils import update_wiki_pages
 from subprocess import Popen, PIPE, STDOUT
+from fundamentals.renderer import list_of_dictionaries
+from .database_cleaner import database_cleaner
+from .commonutils import update_wiki_pages
 from sherlock.imports import veron as veronImporter
-from sherlock.imports import marshall as marshallImporter
 from sherlock.imports import ifs as ifsImporter
 from sherlock.imports import ned_d as nedImporter
 from sherlock.imports import ned as nedStreamImporter
 from sherlock.commonutils import update_wiki_pages
 from sherlock import transient_classifier
-# from ..__init__ import *
+
+
+def tab_complete(text, state):
+    return (glob.glob(text + '*') + [None])[state]
 
 
 def main(arguments=None):
     """
-    The main function used when ``cl_utils.py`` is run as a single script from the cl, or when installed as a cl command
-
-    .. todo ::
-
-        - update key arguments values and definitions with defaults
-        - update return values and definitions
-        - update usage examples and text
-        - update docstring text
-        - check sublime snippet exists
-        - clip any useful text to docs mindmap
-        - regenerate the docs and check redendering of this docstring
+    *The main function used when `cl_utils.py` is run as a single script from the cl, or when installed as a cl command*
     """
     # setup the command-line util settings
-
     su = tools(
         arguments=arguments,
         docString=__doc__,
         logLevel="WARNING",
         options_first=False,
+        distributionName="qub-sherlock",
         projectName="sherlock",
-        distributionName="qub-sherlock"
+        defaultSettingsFile=True
     )
     arguments, settings, log, dbConn = su.setup()
 
-    # unpack remaining cl arguments using `exec` to setup the variable names
-    # automatically
-    for arg, val in arguments.iteritems():
+    # tab completion for raw_input
+    readline.set_completer_delims(' \t\n;')
+    readline.parse_and_bind("tab: complete")
+    readline.set_completer(tab_complete)
+
+    # UNPACK REMAINING CL ARGUMENTS USING `EXEC` TO SETUP THE VARIABLE NAMES
+    # AUTOMATICALLY
+    a = {}
+    for arg, val in list(arguments.items()):
         if arg[0] == "-":
             varname = arg.replace("-", "") + "Flag"
         else:
             varname = arg.replace("<", "").replace(">", "")
-            if varname == "import":
-                varname = "iimport"
-        if isinstance(val, str) or isinstance(val, unicode):
-            exec(varname + " = '%s'" % (val,))
-        else:
-            exec(varname + " = %s" % (val,))
+        a[varname] = val
         if arg == "--dbConn":
             dbConn = val
+            a["dbConn"] = val
         log.debug('%s = %s' % (varname, val,))
 
     ## START LOGGING ##
     startTime = times.get_now_sql_datetime()
-    log.debug(
+    log.info(
         '--- STARTING TO RUN THE cl_utils.py AT %s' %
         (startTime,))
 
-    # call the worker function
-    # x-if-settings-or-database-credientials
-    if init:
+    # set options interactively if user requests
+    if "interactiveFlag" in a and a["interactiveFlag"]:
+
+        # load previous settings
+        moduleDirectory = os.path.dirname(__file__) + "/resources"
+        pathToPickleFile = "%(moduleDirectory)s/previousSettings.p" % locals()
+        try:
+            with open(pathToPickleFile):
+                pass
+            previousSettingsExist = True
+        except:
+            previousSettingsExist = False
+        previousSettings = {}
+        if previousSettingsExist:
+            previousSettings = pickle.load(open(pathToPickleFile, "rb"))
+
+        # x-raw-input
+        # x-boolean-raw-input
+        # x-raw-input-with-default-value-from-previous-settings
+
+        # save the most recently used requests
+        pickleMeObjects = []
+        pickleMe = {}
+        theseLocals = locals()
+        for k in pickleMeObjects:
+            pickleMe[k] = theseLocals[k]
+        pickle.dump(pickleMe, open(pathToPickleFile, "wb"))
+
+    if a["init"]:
         from os.path import expanduser
         home = expanduser("~")
         filepath = home + "/.config/sherlock/sherlock.yaml"
-        cmd = """open %(filepath)s""" % locals()
-        p = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
         try:
             cmd = """open %(filepath)s""" % locals()
             p = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
@@ -140,7 +154,30 @@ def main(arguments=None):
             p = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
         except:
             pass
+        return
 
+    init = a["init"]
+    match = a["match"]
+    dbmatch = a["dbmatch"]
+    clean = a["clean"]
+    wiki = a["wiki"]
+    iimport = a["import"]
+    ned = a["ned"]
+    cat = a["cat"]
+    stream = a["stream"]
+    info = a["info"]
+    ra = a["ra"]
+    dec = a["dec"]
+    radiusArcsec = a["radiusArcsec"]
+    cat_name = a["cat_name"]
+    stream_name = a["stream_name"]
+    skipNedUpdateFlag = a["skipNedUpdateFlag"]
+    skipMagUpdateFlag = a["skipMagUpdateFlag"]
+    settingsFlag = a["settingsFlag"]
+    verboseFlag = a["verboseFlag"]
+    updateFlag = a["updateFlag"]
+
+    # CALL FUNCTIONS/OBJECTS
     if match or dbmatch:
         if verboseFlag:
             verbose = 2
@@ -213,12 +250,6 @@ def main(arguments=None):
             )
             catalogue.ingest()
     if iimport and stream:
-        if "marshall" in stream_name:
-            stream = marshallImporter(
-                log=log,
-                settings=settings,
-            )
-            stream.ingest()
         if "ifs" in stream_name:
             stream = ifsImporter(
                 log=log,
@@ -238,7 +269,7 @@ def main(arguments=None):
         classifier.classify()
 
     if info:
-        print "sherlock-catalogues"
+        print("sherlock-catalogues")
         wiki = update_wiki_pages(
             log=log,
             settings=settings
@@ -250,20 +281,20 @@ def main(arguments=None):
             listOfDictionaries=table
         )
         tableData = dataSet.reST(filepath=None)
-        print tableData
-        print
+        print(tableData)
+        print()
 
-        print "Crossmatch Streams"
+        print("Crossmatch Streams")
         table = list(wiki._get_stream_view_infos(trimmed=True))
         dataSet = list_of_dictionaries(
             log=log,
             listOfDictionaries=table
         )
         tableData = dataSet.reST(filepath=None)
-        print tableData
-        print
+        print(tableData)
+        print()
 
-        print "Views on Catalogues and Streams"
+        print("Views on Catalogues and Streams")
 
         table = list(wiki._get_view_infos(trimmed=True))
         dataSet = list_of_dictionaries(
@@ -271,7 +302,7 @@ def main(arguments=None):
             listOfDictionaries=table
         )
         tableData = dataSet.reST(filepath=None)
-        print tableData
+        print(tableData)
 
     if "dbConn" in locals() and dbConn:
         dbConn.commit()
@@ -279,11 +310,10 @@ def main(arguments=None):
     ## FINISH LOGGING ##
     endTime = times.get_now_sql_datetime()
     runningTime = times.calculate_time_difference(startTime, endTime)
-    log.debug('-- FINISHED ATTEMPT TO RUN THE cl_utils.py AT %s (RUNTIME: %s) --' %
-              (endTime, runningTime, ))
+    log.info('-- FINISHED ATTEMPT TO RUN THE cl_utils.py AT %s (RUNTIME: %s) --' %
+             (endTime, runningTime, ))
 
     return
 
-
 if __name__ == '__main__':
     main()
