@@ -5,13 +5,9 @@
 
 :Author:
     David Young
-
-:Date Created:
-    November 18, 2016
 """
 import os
 
-
 def getpackagepath():
     """
      *Get the root path for this python package - used in unit testing code*
